pub struct Rate { /* private fields */ }Expand description
An exact positive video frame rate, in frames per second.
Implementations
Sourceimpl Rate
impl Rate
Sourcepub fn new(numerator: u32, denominator: u32) -> Result<Self, RateError>
pub fn new(numerator: u32, denominator: u32) -> Result<Self, RateError>
Construct an exact rate from a numerator and denominator.
Sourcepub fn from_f64(value: f64) -> Result<Self, RateError>
pub fn from_f64(value: f64) -> Result<Self, RateError>
Approximate a finite catalog rate using 32-bit rational components.
Sourcepub fn denominator(self) -> u32
pub fn denominator(self) -> u32
The frames-per-second denominator.